@@ -1,9 +1,11 @@
+from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery, NumericQuery
 from maggma.api.resource import ReadOnlyResource
-from emmet.core.chemenv import ChemEnvDoc
+
 from emmet.api.core.global_header import GlobalHeaderProcessor
-from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
-from emmet.api.routes.materials.query_operators import MultiMaterialIDQuery
 from emmet.api.core.settings import MAPISettings
+from emmet.api.routes.materials.query_operators import MultiMaterialIDQuery
+from emmet.api.routes.chemenv.query_operators import ChemEnvQuery
+from emmet.core.chemenv import ChemEnvDoc
 
 
 def chemenv_resource(chemenv_store):
@@ -12,17 +14,16 @@ def chemenv_resource(chemenv_store):
         ChemEnvDoc,
         query_operators=[
             MultiMaterialIDQuery(),
+            ChemEnvQuery(),
+            NumericQuery(model=ChemEnvDoc, excluded_fields=["valences"]),
             SortQuery(),
             PaginationQuery(),
-            SparseFieldsQuery(
-                ChemEnvDoc,
-                default_fields=["material_id", "formula_pretty", "last_updated"],
-            ),
+            SparseFieldsQuery(ChemEnvDoc, default_fields=["material_id", "formula_pretty", "last_updated"],),
         ],
         header_processor=GlobalHeaderProcessor(),
         tags=["Chemical Environment"],
         disable_validation=True,
-        timeout=MAPISettings().TIMEOUT
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
